@@ -96,7 +96,12 @@ class  MixerRunner(AbstractRunner):
         print('size after filtering')
         print(raw_data.shape)
         raw_data['close_return'] = raw_data['close'].pct_change()
-        y = raw_data['close_return']
+        raw_data['shifted_close_return'] = raw_data['close_return'].shift(-1)
+        raw_data = raw_data.iloc[:-1]
+        y_true = raw_data['close_return']
+
+
+        y = raw_data['shifted_close_return']
         X = raw_data[[col for col in raw_data.columns if 'signal' in col]]
 
         print('predictors shape')
@@ -118,6 +123,12 @@ class  MixerRunner(AbstractRunner):
             method = chosen_method,
             display = True)
 
+        forecasted_series = forecasted_series.shift(1)
+        discrete_two_states_forecasting_series = discrete_two_states_forecasting_series.shift(1)
+        discrete_two_states_forecasting_series_lo = discrete_two_states_forecasting_series_lo.shift(1)
+        discrete_three_states_forecasting_series = discrete_three_states_forecasting_series.shift(1)
+        discrete_three_states_forecasting_series_lo = discrete_three_states_forecasting_series_lo.shift(1)
+
         print('mixing backtest done')
         features_importances = features_importances.sum(axis = 0)
         print('features importance')
@@ -181,7 +192,7 @@ class  MixerRunner(AbstractRunner):
         print('scale three min prediction signal')
         print(min(forecasted_series_scale_three))
 
-        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=forecasted_series_scale_one, y_true = y, transaction_cost=transaction_cost, print_turnover=False)
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=forecasted_series_scale_one, y_true = y_true, transaction_cost=transaction_cost, print_turnover=False)
         sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period= self.number_per_year, from_ret=True)
         sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period= self.number_per_year, from_ret=True)
         print('underlying sharpe')
@@ -190,7 +201,7 @@ class  MixerRunner(AbstractRunner):
         print(sharpe_strat)
         saver.saveAll(continuous_saving_key, perf_df)
 
-        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=forecasted_series_scale_two, y_true = y, transaction_cost=transaction_cost, print_turnover=False)
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=forecasted_series_scale_two, y_true = y_true, transaction_cost=transaction_cost, print_turnover=False)
         sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period= self.number_per_year, from_ret=True)
         sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period= self.number_per_year, from_ret=True)
         print('underlying sharpe')
@@ -199,7 +210,7 @@ class  MixerRunner(AbstractRunner):
         print(sharpe_strat)
         saver.saveAll(continuous_saving_key_scale_one, perf_df)
 
-        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=forecasted_series_scale_three, y_true = y, transaction_cost=transaction_cost, print_turnover=False)
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=forecasted_series_scale_three, y_true = y_true, transaction_cost=transaction_cost, print_turnover=False)
         sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period= self.number_per_year, from_ret=True)
         sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period= self.number_per_year, from_ret=True)
         print('underlying sharpe')
@@ -210,7 +221,7 @@ class  MixerRunner(AbstractRunner):
 
 
         #saving the 2 states signal
-        perf_df = signal_utility.reconstitute_prediction_perf(y_pred= discrete_two_states_forecasting_series , y_true = y, transaction_cost=transaction_cost, print_turnover=False)
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred= discrete_two_states_forecasting_series , y_true = y_true, transaction_cost=transaction_cost, print_turnover=False)
         sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period= self.number_per_year, from_ret=True)
         sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period= self.number_per_year, from_ret=True)
         print('underlying sharpe')
@@ -220,7 +231,7 @@ class  MixerRunner(AbstractRunner):
         saver.saveAll(two_states_saving_key, perf_df)
 
         # saving the 2 states signal long only
-        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=discrete_two_states_forecasting_series_lo, y_true=y,
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=discrete_two_states_forecasting_series_lo, y_true=y_true,
                                                               transaction_cost=transaction_cost, print_turnover=False)
         sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period=self.number_per_year, from_ret=True)
         sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period=self.number_per_year, from_ret=True)
@@ -232,7 +243,7 @@ class  MixerRunner(AbstractRunner):
 
 
         #saving the 3 states signal
-        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=discrete_three_states_forecasting_series, y_true = y, transaction_cost=transaction_cost, print_turnover=False)
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=discrete_three_states_forecasting_series, y_true = y_true, transaction_cost=transaction_cost, print_turnover=False)
         sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period= self.number_per_year, from_ret=True)
         sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period= self.number_per_year, from_ret=True)
         print('underlying sharpe')
@@ -242,7 +253,7 @@ class  MixerRunner(AbstractRunner):
         saver.saveAll(three_states_saving_key, perf_df)
 
         # saving the 3 states signal long only
-        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=discrete_three_states_forecasting_series_lo, y_true=y,
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=discrete_three_states_forecasting_series_lo, y_true=y_true,
                                                               transaction_cost=transaction_cost, print_turnover=False)
         sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period=self.number_per_year, from_ret=True)
         sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period=self.number_per_year, from_ret=True)
